@@ -4,7 +4,7 @@ import os
 import functools
 
 # Disabled for now due to: #2228, #2230
-# import setuptools.distutils_patch  # noqa: F401
+import setuptools.distutils_patch  # noqa: F401
 
 import distutils.core
 import distutils.filelist
